==> meteor-bootstrap_key-value-tag-input-1.0.0.tgz: package/src/keyValueTypes/DateKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
import * as moment_ from "moment";
var moment = moment_;
var symbolForOperator = {
    "<": "<",
    ">": ">",
    "<=": "≤",
    ">=": "≥",
    "!=": "≠",
    "=": "=",
};
var operatorsAndSymbols = ["<", ">", "<=", ">=", "!=", "=", "≤", "≥", "≠"];
function toSymbol(op) {
    // @ts-ignore missing index signature of mapped type
    return symbolForOperator[op] || op;
}
var selectorForOperator = {
    "<": "$lt",
    ">": "$gt",
    "<=": "$lte",
    ">=": "$gte",
    "!=": "$ne",
    "=": "$eq",
};
function toSelector(op) {
    // @ts-ignore missing index signature of mapped type
    return selectorForOperator[op];
}
var DateKeyValueType = /** @class */ (function (_super) {
    __extends(DateKeyValueType, _super);
    function DateKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._dateFormat = "YYYY-MM-DD";
        _this._dateParseFormats = ["YYYY-MM-DD", "YY-MM-DD", "MM-DD"];
        return _this;
    }
    DateKeyValueType.mongoSelectorFor = function (value) {
        var _a;
        return _a = {}, _a[toSelector(value.operator)] = value.date, _a;
    };
    Object.defineProperty(DateKeyValueType.prototype, "dateFormat", {
        set: function (dateFormat) {
            this._dateFormat = dateFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateKeyValueType.prototype, "dateParseFormats", {
        set: function (dateParseFormats) {
            this._dateParseFormats = dateParseFormats;
        },
        enumerable: true,
        configurable: true
    });
    DateKeyValueType.prototype.getSuggestions = function (prefix) {
        var _this = this;
        var parsed = this.parseString(prefix);
        // empty input or invalid input or fallback "="
        if (prefix === "" || !parsed || (parsed.operator === "=" && !prefix.startsWith("="))) {
            var date_1 = new Date();
            var operators = Object.keys(symbolForOperator);
            if (prefix !== "") {
                date_1 = parsed ? parsed.date : date_1;
                var filteredOperators = operatorsAndSymbols.filter(function (op) { return op.startsWith(prefix); });
                operators = filteredOperators.length > 0 ? filteredOperators : operators;
            }
            return operators.map(function (operator) { return ({
                display: _this.display({ operator: operator, date: date_1 }),
                value: _this.editText({ operator: operator, date: date_1 }),
            }); });
        }
        else {
            return [];
        }
    };
    DateKeyValueType.prototype.parseString = function (val) {
        var value = val.trim();
        if (value === "") {
            value = "=" + new Date();
        }
        value = value.replace(/\s/g, ""); // remove spaces
        var match = value.replace("≥", ">=")
            .replace("≤", "<=")
            .replace("<>", "!=")
            .replace("≠", "!=")
            .replace("==", "=")
            .match(/^(<=|<|>=|>|!=|=)?(.+)/);
        if (match) {
            var parsedDate = moment.utc(match[2], this._dateParseFormats, true);
            if (parsedDate.isValid()) {
                return {
                    operator: match[1] || "=",
                    date: parsedDate.toDate(),
                };
            }
            else {
                return undefined;
            }
        }
        else {
            return undefined;
        }
    };
    DateKeyValueType.prototype.checkValue = function (val) {
        if (Object.keys(symbolForOperator).includes(val.operator) && val.date instanceof Date && !isNaN(val.date)) {
            return val;
        }
        else {
            return undefined;
        }
    };
    DateKeyValueType.prototype.display = function (value) {
        return { text: toSymbol(value.operator) + " " + moment(value.date).format(this._dateFormat) };
    };
    DateKeyValueType.prototype.editText = function (value) {
        return this.display(value).text;
    };
    return DateKeyValueType;
}(KeyValueType));
export default DateKeyValueType;

==> meteor-bootstrap_key-value-tag-input-2.3.0.tgz: package/src/keyValueTypes/DateKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
import moment from "moment";
var symbolForOperator = {
    "<": "<",
    ">": ">",
    "<=": "≤",
    ">=": "≥",
    "!=": "≠",
    "=": "=",
};
var operatorsAndSymbols = ["<", ">", "<=", ">=", "!=", "=", "≤", "≥", "≠"];
function toSymbol(op) {
    // @ts-ignore missing index signature of mapped type
    return symbolForOperator[op] || op;
}
var selectorForOperator = {
    "<": "$lt",
    ">": "$gt",
    "<=": "$lte",
    ">=": "$gte",
    "!=": "$ne",
    "=": "$eq",
};
function toSelector(op) {
    // @ts-ignore missing index signature of mapped type
    return selectorForOperator[op];
}
var DateKeyValueType = /** @class */ (function (_super) {
    __extends(DateKeyValueType, _super);
    function DateKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._dateFormat = "YYYY-MM-DD";
        _this._dateParseFormats = ["YYYY-MM-DD", "YY-MM-DD", "MM-DD"];
        return _this;
    }
    DateKeyValueType.mongoSelectorFor = function (value) {
        var _a;
        return _a = {}, _a[toSelector(value.operator)] = value.date, _a;
    };
    Object.defineProperty(DateKeyValueType.prototype, "dateFormat", {
        set: function (dateFormat) {
            this._dateFormat = dateFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateKeyValueType.prototype, "dateParseFormats", {
        set: function (dateParseFormats) {
            this._dateParseFormats = dateParseFormats;
        },
        enumerable: true,
        configurable: true
    });
    DateKeyValueType.prototype.getSuggestions = function (prefix) {
        var _this = this;
        var parsed = this.parseString(prefix);
        // empty input or invalid input or fallback "="
        if (prefix === "" || !parsed || (parsed.operator === "=" && !prefix.startsWith("="))) {
            var date_1 = new Date();
            var operators = Object.keys(symbolForOperator);
            if (prefix !== "") {
                date_1 = parsed ? parsed.date : date_1;
                var filteredOperators = operatorsAndSymbols.filter(function (op) { return op.startsWith(prefix); });
                operators = filteredOperators.length > 0 ? filteredOperators : operators;
            }
            return operators.map(function (operator) { return ({
                display: _this.display({ operator: operator, date: date_1 }),
                value: _this.editText({ operator: operator, date: date_1 }),
            }); });
        }
        else {
            return [];
        }
    };
    DateKeyValueType.prototype.parseString = function (val) {
        var value = val.trim();
        if (value === "") {
            value = "=" + new Date();
        }
        value = value.replace(/\s/g, ""); // remove spaces
        var match = value.replace("≥", ">=")
            .replace("≤", "<=")
            .replace("<>", "!=")
            .replace("≠", "!=")
            .replace("==", "=")
            .match(/^(<=|<|>=|>|!=|=)?(.+)/);
        if (match) {
            var parsedDate = moment.utc(match[2], this._dateParseFormats, true);
            if (parsedDate.isValid()) {
                return {
                    operator: match[1] || "=",
                    date: parsedDate.toDate(),
                };
            }
            else {
                return undefined;
            }
        }
        else {
            return undefined;
        }
    };
    DateKeyValueType.prototype.checkValue = function (val) {
        if (Object.keys(symbolForOperator).includes(val.operator) && val.date instanceof Date && !isNaN(val.date)) {
            return val;
        }
        else {
            return undefined;
        }
    };
    DateKeyValueType.prototype.display = function (value) {
        return { text: toSymbol(value.operator) + " " + moment(value.date).format(this._dateFormat) };
    };
    DateKeyValueType.prototype.editText = function (value) {
        return this.display(value).text;
    };
    return DateKeyValueType;
}(KeyValueType));
export default DateKeyValueType;
